==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QTouchEvent_shell.h <==
#ifndef QTOUCHEVENT_SHELL_H
#define QTOUCHEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qobject.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QTouchEvent_shell : public QTouchEvent, public QtJambiShellInterface
{
public:
    QTouchEvent_shell(QEvent::Type eventType0, const QPointingDevice* device1, Qt::KeyboardModifiers modifiers2, QEventPoint::States touchPointStates3, const QList<QEventPoint>& touchPoints4 = {});
    QTouchEvent_shell(QEvent::Type eventType0, const QPointingDevice* device1 = nullptr, Qt::KeyboardModifiers modifiers2 = Qt::NoModifier, const QList<QEventPoint>& touchPoints3 = {});
    QTouchEvent_shell(const QTouchEvent& arg__1);
    ~QTouchEvent_shell() override;

    QTouchEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTouchEvent_access : public QTouchEvent
{
    void __qt_assign_cref_QTouchEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setTarget_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID target0);
    void setTouchPointStates_cref_QEventPoint_States(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint touchPointStates0);
};

#endif // QTOUCHEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QTouchEvent_shell.h <==
#ifndef QTOUCHEVENT_SHELL_H
#define QTOUCHEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qobject.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QTouchEvent_shell : public QTouchEvent, public QtJambiShellInterface
{
public:
    QTouchEvent_shell(QEvent::Type eventType0, const QPointingDevice* device1, Qt::KeyboardModifiers modifiers2, QEventPoint::States touchPointStates3, const QList<QEventPoint>& touchPoints4 = {});
    QTouchEvent_shell(QEvent::Type eventType0, const QPointingDevice* device1 = nullptr, Qt::KeyboardModifiers modifiers2 = Qt::NoModifier, const QList<QEventPoint>& touchPoints3 = {});
    QTouchEvent_shell(const QTouchEvent& arg__1);
    ~QTouchEvent_shell() override;

    QTouchEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTouchEvent_access : public QTouchEvent
{
    void __qt_assign_cref_QTouchEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setTarget_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID target0);
    void setTouchPointStates_cref_QEventPoint_States(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint touchPointStates0);
};

#endif // QTOUCHEVENT_SHELL_H
